@@ -1,5 +1,4 @@
-from src.cli.cli import cli
-
+from cli.cli import cli
 
 def main():
     cli()
